@@ -94,14 +94,14 @@ typedef struct _parseCallbacks {
     void (*add_element)(PInfo pi, const char *ename, Attr attrs, int hasChildren);
     void (*end_element)(PInfo pi, const char *ename);
     void (*finish)(PInfo pi);
-} * ParseCallbacks;
+} *ParseCallbacks;
 
 typedef struct _circArray {
     VALUE         obj_array[1024];
     VALUE        *objs;
     unsigned long size; /* allocated size or initial array size */
     unsigned long cnt;
-} * CircArray;
+} *CircArray;
 
 typedef struct _options {
     char           encoding[64];     // encoding, stored in the option to avoid GC invalidation in default values
@@ -128,8 +128,8 @@ typedef struct _options {
     struct _hints *html_hints;       // html hints
     VALUE          attr_key_mod;
     VALUE          element_key_mod;
-    rb_encoding *rb_enc;
-} * Options;
+    rb_encoding   *rb_enc;
+} *Options;
 
 // parse information structure
 struct _pInfo {
@@ -146,7 +146,7 @@ struct _pInfo {
     VALUE              *marked;
     int                 mark_size;  // allocated size
     int                 mark_cnt;
-    char                last;  // last character read, rarely set
+    char                last;       // last character read, rarely set
 };
 
 extern VALUE ox_parse(char *xml, size_t len, ParseCallbacks pcb, char **endp, Options options, Err err);
@@ -205,11 +205,6 @@ extern ID ox_start_element_id;
 extern ID ox_string_id;
 extern ID ox_text_id;
 extern ID ox_to_c_id;
-extern ID ox_to_s_id;
-extern ID ox_to_sym_id;
-extern ID ox_tv_sec_id;
-extern ID ox_tv_nsec_id;
-extern ID ox_tv_usec_id;
 extern ID ox_value_id;
 
 extern rb_encoding *ox_utf8_encoding;
