@@ -55,7 +55,7 @@ static char read_text(SaxDrive dr);
 static char read_jump(SaxDrive dr, const char *pat);
 static char read_attrs(SaxDrive dr, char c, char termc, char term2, int is_xml, int eq_req, Hint h);
 static char read_name_token(SaxDrive dr);
-static char read_quoted_value(SaxDrive dr);
+static char read_quoted_value(SaxDrive dr, bool inst);
 
 static void hint_clear_empty(SaxDrive dr);
 static Nv   hint_try_close(SaxDrive dr, const char *name);
@@ -117,7 +117,7 @@ static void attr_text(SaxDrive dr, VALUE name, char *value, long pos, long line,
     VALUE args[2];
 
     args[0] = name;
-    if (dr->options.convert_special) {
+    if (dr->options.convert_special && '\0' != value[0]) {
         ox_sax_collapse_special(dr, value, pos, line, col);
     }
     args[1] = rb_str_new2(value);
@@ -469,7 +469,7 @@ DONE:
         Nv   sp;
 
         for (sp = dr->stack.tail - 1; dr->stack.head <= sp; sp--) {
-            snprintf(msg, sizeof(msg) - 1, "%selement '%s' not closed", EL_MISMATCH, sp->name);
+            snprintf(msg, sizeof(msg) - 1, "%selement '%s' not closed", EL_MISMATCH, nv_name(sp));
             ox_sax_drive_error_at(dr, msg, dr->buf.pos, dr->buf.line, dr->buf.col);
             end_element_cb(dr, sp->val, dr->buf.pos, dr->buf.line, dr->buf.col, sp->hint);
         }
@@ -761,16 +761,19 @@ CB:
  * code.
  */
 static char read_element_start(SaxDrive dr) {
-    const char    *ename = 0;
-    volatile VALUE name  = Qnil;
+    const char    *ename = NULL;
+    char           ebuf[128];
+    size_t         nlen;
+    volatile VALUE name = Qnil;
     char           c;
-    int            closed;
     long           pos       = (long)(dr->buf.pos);
     long           line      = (long)(dr->buf.line);
     long           col       = (long)(dr->buf.col);
     Hint           h         = NULL;
     int            stackless = 0;
     Nv             parent    = stack_peek(&dr->stack);
+    bool           closed;
+    bool           efree = false;
 
     if ('\0' == (c = read_name_token(dr))) {
         return '\0';
@@ -790,6 +793,7 @@ static char read_element_start(SaxDrive dr) {
         0 == strcasecmp("html", dr->buf.str)) {
         dr->options.hints = ox_hints_html();
     }
+    nlen = dr->buf.tail - dr->buf.str - 1;
     if (NULL != dr->options.hints) {
         hint_clear_empty(dr);
         h = ox_hint_find(dr->options.hints, dr->buf.str);
@@ -810,7 +814,7 @@ static char read_element_start(SaxDrive dr) {
                 if (rb_respond_to(dr->handler, ox_abort_id)) {
                     VALUE args[1];
 
-                    args[0] = str2sym(dr, dr->buf.str, dr->buf.tail - dr->buf.str - 1, NULL);
+                    args[0] = str2sym(dr, dr->buf.str, nlen, NULL);
                     rb_funcall2(dr->handler, ox_abort_id, 1, args);
                 }
                 dr->abort = true;
@@ -825,7 +829,7 @@ static char read_element_start(SaxDrive dr) {
             if (0 != top_nv) {
                 char msg[256];
 
-                if (!h->nest && NestOverlay != h->overlay && 0 == strcasecmp(top_nv->name, h->name)) {
+                if (!h->nest && NestOverlay != h->overlay && nv_same_name(top_nv, h->name, true)) {
                     snprintf(msg,
                              sizeof(msg) - 1,
                              "%s%s can not be nested in a %s document, closing previous.",
@@ -842,7 +846,7 @@ static char read_element_start(SaxDrive dr) {
                     int          ok = 0;
 
                     for (p = h->parents; 0 != *p; p++) {
-                        if (0 == strcasecmp(*p, top_nv->name)) {
+                        if (nv_same_name(top_nv, *p, true)) {
                             ok = 1;
                             break;
                         }
@@ -853,7 +857,7 @@ static char read_element_start(SaxDrive dr) {
                                  "%s%s can not be a child of a %s in a %s document.",
                                  INV_ELEMENT,
                                  h->name,
-                                 top_nv->name,
+                                 nv_name(top_nv),
                                  dr->options.hints->name);
                         ox_sax_drive_error(dr, msg);
                     }
@@ -861,7 +865,17 @@ static char read_element_start(SaxDrive dr) {
             }
         }
     }
-    name = str2sym(dr, dr->buf.str, dr->buf.tail - dr->buf.str - 1, &ename);
+    name = str2sym(dr, dr->buf.str, nlen, &ename);
+    if (NULL == ename) {
+        if (sizeof(ebuf) <= nlen) {
+            ename = ox_strndup(dr->buf.str, nlen);
+            efree = true;
+        } else {
+            memcpy(ebuf, dr->buf.str, nlen);
+            ebuf[nlen] = '\0';
+            ename      = ebuf;
+        }
+    }
     if (dr->has_start_element && 0 >= dr->blocked &&
         (NULL == h || ActiveOverlay == h->overlay || NestOverlay == h->overlay)) {
         VALUE args[1];
@@ -873,9 +887,9 @@ static char read_element_start(SaxDrive dr) {
         rb_funcall2(dr->handler, ox_start_element_id, 1, args);
     }
     if ('/' == c) {
-        closed = 1;
+        closed = true;
     } else if ('>' == c) {
-        closed = 0;
+        closed = false;
     } else {
         buf_protect(&dr->buf);
         c = read_attrs(dr, c, '/', '>', 0, 0, h);
@@ -894,7 +908,7 @@ static char read_element_start(SaxDrive dr) {
     } else if (stackless) {
         end_element_cb(dr, name, pos, line, col, h);
     } else if (NULL != h && h->jump) {
-        stack_push(&dr->stack, ename, name, h);
+        stack_push(&dr->stack, ename, nlen, name, h);
         if ('>' != c) {
             ox_sax_drive_error(dr, WRONG_CHAR "element not closed");
             return c;
@@ -902,13 +916,16 @@ static char read_element_start(SaxDrive dr) {
         read_jump(dr, h->name);
         return '<';
     } else {
-        stack_push(&dr->stack, ename, name, h);
+        stack_push(&dr->stack, ename, nlen, name, h);
+    }
+    if (efree) {
+        free((char *)ename);
     }
     if ('>' != c) {
         ox_sax_drive_error(dr, WRONG_CHAR "element not closed");
         return c;
     }
-    dr->buf.str = 0;
+    dr->buf.str = NULL;
 
     return buf_get(&dr->buf);
 }
@@ -917,7 +934,7 @@ static Nv stack_rev_find(SaxDrive dr, const char *name) {
     Nv nv;
 
     for (nv = dr->stack.tail - 1; dr->stack.head <= nv; nv--) {
-        if (0 == (dr->options.smart ? strcasecmp(name, nv->name) : strcmp(name, nv->name))) {
+        if (nv_same_name(nv, name, dr->options.smart)) {
             return nv;
         }
     }
@@ -942,7 +959,7 @@ static char read_element_end(SaxDrive dr) {
     // c should be > and current is one past so read another char
     c  = buf_get(&dr->buf);
     nv = stack_peek(&dr->stack);
-    if (0 != nv && 0 == (dr->options.smart ? strcasecmp(dr->buf.str, nv->name) : strcmp(dr->buf.str, nv->name))) {
+    if (0 != nv && nv_same_name(nv, dr->buf.str, dr->options.smart)) {
         name = nv->val;
         h    = nv->hint;
         stack_pop(&dr->stack);
@@ -995,7 +1012,7 @@ static char read_element_end(SaxDrive dr) {
                          "%selement '%s' close does not match '%s' open",
                          EL_MISMATCH,
                          dr->buf.str,
-                         nv->name);
+                         nv_name(nv));
                 ox_sax_drive_error_at(dr, msg, pos, line, col);
                 for (nv = stack_pop(&dr->stack); match < nv; nv = stack_pop(&dr->stack)) {
                     end_element_cb(dr, nv->val, pos, line, col, nv->hint);
@@ -1202,6 +1219,7 @@ static char read_attrs(SaxDrive dr, char c, char termc, char term2, int is_xml,
             c = buf_next_non_white(&dr->buf);
         }
         if ('=' != c) {
+	    // TBD allow in smart mode
             if (eq_req) {
                 dr->err = 1;
                 return c;
@@ -1213,8 +1231,9 @@ static char read_attrs(SaxDrive dr, char c, char termc, char term2, int is_xml,
             pos        = dr->buf.pos + 1;
             line       = dr->buf.line;
             col        = dr->buf.col + 1;
-            c          = read_quoted_value(dr);
+            c          = read_quoted_value(dr, '?' == termc);
             attr_value = dr->buf.str;
+
             if (is_encoding) {
                 dr->encoding = rb_enc_find(dr->buf.str);
                 is_encoding  = 0;
@@ -1279,10 +1298,11 @@ static char read_name_token(SaxDrive dr) {
     return '\0';
 }
 
-/* The character after the quote or if there is no quote, the character after the word is returned. dr->buf.tail is one
- * past that. dr->buf.str will point to the token which will be '\0' terminated.
+/* The character after the quote or if there is no quote, the character after
+ * the word is returned. dr->buf.tail is one past that. dr->buf.str will point
+ * to the token which will be '\0' terminated.
  */
-static char read_quoted_value(SaxDrive dr) {
+static char read_quoted_value(SaxDrive dr, bool inst) {
     char c;
 
     c = buf_get(&dr->buf);
@@ -1306,19 +1326,27 @@ static char read_quoted_value(SaxDrive dr) {
     }
     // not quoted, look for something that terminates the string
     dr->buf.str = dr->buf.tail - 1;
-    ox_sax_drive_error(dr, WRONG_CHAR "attribute value not in quotes");
+    // TBD if smart or html then no error
+    if (!(dr->options.smart && ox_hints_html() != dr->options.hints)) {
+	ox_sax_drive_error(dr, WRONG_CHAR "attribute value not in quotes");
+    }
     while ('\0' != (c = buf_get(&dr->buf))) {
         switch (c) {
         case ' ':
             // case '/':
         case '>':
-        case '?':  // for instructions
         case '\t':
         case '\n':
         case '\r':
             *(dr->buf.tail - 1) = '\0'; /* terminate value */
             // dr->buf.tail is in the correct position, one after the word terminator
             return c;
+        case '?':  // for instructions
+	    if (inst) {
+		*(dr->buf.tail - 1) = '\0'; /* terminate value */
+		return c;
+	    }
+	    break;
         default: break;
         }
     }
@@ -1462,18 +1490,18 @@ int ox_sax_collapse_special(SaxDrive dr, char *str, long pos, long line, long co
             break;
         }
         case '\r':
-	    s++;
+            s++;
             if ('\n' == *s) {
-		continue;
-	    }
-	    line++;
-	    col = 1;
+                continue;
+            }
+            line++;
+            col  = 1;
             *b++ = '\n';
-	    break;
-	case '\n':
-	    line++;
-	    col = 0;
-	    // fall through
+            break;
+        case '\n':
+            line++;
+            col = 0;
+            // fall through
         default:
             col++;
             *b++ = *s++;
@@ -1509,7 +1537,7 @@ static Nv hint_try_close(SaxDrive dr, const char *name) {
         return 0;
     }
     for (nv = stack_peek(&dr->stack); 0 != nv; nv = stack_peek(&dr->stack)) {
-        if (0 == strcasecmp(name, nv->name)) {
+        if (nv_same_name(nv, name, true)) {
             stack_pop(&dr->stack);
             return nv;
         }
