@@ -1,6 +1,4 @@
-
 module Ox
-
   # An Element represents a element of an XML document. It has a name,
   # attributes, and sub-nodes.
   #
@@ -58,7 +56,8 @@ module Ox
     # so multiple appends can be chained together.
     # - +node+ [Node] Node to append to the nodes array
     def <<(node)
-      raise "argument to << must be a String or Ox::Node." unless node.is_a?(String) or node.is_a?(Node)
+      raise 'argument to << must be a String or Ox::Node.' unless node.is_a?(String) or node.is_a?(Node)
+
       @nodes = [] if !instance_variable_defined?(:@nodes) or @nodes.nil?
       @nodes << node
       self
@@ -68,7 +67,8 @@ module Ox
     # so multiple appends can be chained together.
     # - +node+ [Node] Node to prepend to the nodes array
     def prepend_child(node)
-      raise "argument to << must be a String or Ox::Node." unless node.is_a?(String) or node.is_a?(Node)
+      raise 'argument to << must be a String or Ox::Node.' unless node.is_a?(String) or node.is_a?(Node)
+
       @nodes = [] if !instance_variable_defined?(:@nodes) or @nodes.nil?
       @nodes.unshift(node)
       self
@@ -80,15 +80,16 @@ module Ox
     # *return* [Boolean] true if both Objects are equivalent, otherwise false.
     def eql?(other)
       return false unless super(other)
-      return false unless self.attributes == other.attributes
-      return false unless self.nodes == other.nodes
+      return false unless attributes == other.attributes
+      return false unless nodes == other.nodes
+
       true
     end
     alias == eql?
 
     # Returns the first String in the elements nodes array or nil if there is
     # no String node.
-    def text()
+    def text
       nodes.each { |n| return n if n.is_a?(String) }
       nil
     end
@@ -97,15 +98,16 @@ module Ox
     # (String) node. Note the existing nodes array is modified and not replaced.
     # - +txt+ [String] to become the only element of the nodes array
     def replace_text(txt)
-      raise "the argument to replace_text() must be a String" unless txt.is_a?(String)
-      @nodes.clear()
+      raise 'the argument to replace_text() must be a String' unless txt.is_a?(String)
+
+      @nodes.clear
       @nodes << txt
     end
 
     # Return true if all the key-value pairs in the cond Hash match the
     # @attributes key-values.
     def attr_match(cond)
-      cond.each_pair { |k,v| return false unless v == @attributes[k.to_sym] || v == @attributes[k.to_s] }
+      cond.each_pair { |k, v| return false unless v == @attributes[k.to_sym] || v == @attributes[k.to_s] }
       true
     end
 
@@ -161,6 +163,7 @@ module Ox
     # - +path+ [String] path to the Nodes to locate
     def locate(path)
       return [self] if path.nil?
+
       found = []
       pa = path.split('/')
       if '*' == path[0]
@@ -183,6 +186,7 @@ module Ox
     # - +children+ [Array] array of OX
     def remove_children(*children)
       return self if children.compact.empty?
+
       recursive_children_removal(children.compact.map { |c| c.object_id })
       self
     end
@@ -198,6 +202,7 @@ module Ox
       del_locate(path.split('/')) unless path.nil?
       self
     end
+
     # Handles the 'easy' API that allows navigating a simple XML by
     # referencing elements and attributes by name.
     # - +id+ [Symbol] element or attribute name
@@ -209,17 +214,20 @@ module Ox
       ids = id.to_s
       i = args[0].to_i # will be 0 if no arg or parsing fails
       nodes.each do |n|
-        if (n.is_a?(Element) || n.is_a?(Instruct)) && (n.value == id || n.value == ids || name_matchs?(n.value, ids))
-          return n if 0 == i
-          has_some = true
-          i -= 1
+        unless (n.is_a?(Element) || n.is_a?(Instruct)) && (n.value == id || n.value == ids || name_matchs?(n.value, ids))
+          next
         end
+        return n if 0 == i
+
+        has_some = true
+        i -= 1
       end
       if instance_variable_defined?(:@attributes)
         return @attributes[id] if @attributes.has_key?(id)
         return @attributes[ids] if @attributes.has_key?(ids)
       end
       return nil if has_some
+
       raise NoMethodError.new("#{ids} not found", name)
     end
 
@@ -228,6 +236,7 @@ module Ox
     # *return* true if the element has a member that matches the provided name.
     def respond_to?(id, inc_all=false)
       return true if super
+
       id_str = id.to_s
       id_sym = id.to_sym
       nodes.each do |n|
@@ -247,10 +256,11 @@ module Ox
       step = path[0]
       if step.start_with?('@') # attribute
         raise InvalidPath.new(path) unless 1 == path.size
+
         if instance_variable_defined?(:@attributes)
           step = step[1..-1]
           sym_step = step.to_sym
-          @attributes.each do |k,v|
+          @attributes.each do |k, v|
             found << v if ('?' == step or k == step or k == sym_step)
           end
         end
@@ -261,6 +271,7 @@ module Ox
         else
           name = step[0..i-1]
           raise InvalidPath.new(path) unless step.end_with?(']')
+
           i += 1
           qual = step[i..i] # step[i] would be better but some rubies (jruby, ree, rbx) take that as a Fixnum.
           if '0' <= qual and qual <= '9'
@@ -270,13 +281,13 @@ module Ox
           end
           index = step[i..-2].to_i
         end
-        if '?' == name or '*' == name
+        if ['?', '*'].include?(name)
           match = nodes
         elsif '^' == name[0..0] # 1.8.7 thinks name[0] is a fixnum
           case name[1..-1]
-           when 'Element'
+          when 'Element'
             match = nodes.select { |e| e.is_a?(Element) }
-           when 'String', 'Text'
+          when 'String', 'Text'
             match = nodes.select { |e| e.is_a?(String) }
           when 'Comment'
             match = nodes.select { |e| e.is_a?(Comment) }
@@ -285,7 +296,7 @@ module Ox
           when 'DocType'
             match = nodes.select { |e| e.is_a?(DocType) }
           else
-            #puts "*** no match on #{name}"
+            # puts "*** no match on #{name}"
             match = []
           end
         else
@@ -302,7 +313,7 @@ module Ox
           when '>'
             match = index <= match.size ? match[index + 1..-1] : []
           when '@'
-            k,v = step[i..-2].split('=')
+            k, v = step[i..-2].split('=')
             if v
               match = match.select { |n| n.is_a?(Element) && (v == n.attributes[k.to_sym] || v == n.attributes[k]) }
             else
@@ -328,10 +339,11 @@ module Ox
       step = path[0]
       if step.start_with?('@') # attribute
         raise InvalidPath.new(path) unless 1 == path.size
+
         if instance_variable_defined?(:@attributes)
           step = step[1..-1]
           sym_step = step.to_sym
-          @attributes.delete_if { |k,v| '?' == step || k.to_sym == sym_step }
+          @attributes.delete_if { |k, v| '?' == step || k.to_sym == sym_step }
         end
       else # element name
         if (i = step.index('[')).nil? # just name
@@ -340,6 +352,7 @@ module Ox
         else
           name = step[0..i-1]
           raise InvalidPath.new(path) unless step.end_with?(']')
+
           i += 1
           qual = step[i..i] # step[i] would be better but some rubies (jruby, ree, rbx) take that as a Fixnum.
           if '0' <= qual and qual <= '9'
@@ -349,13 +362,13 @@ module Ox
           end
           index = step[i..-2].to_i
         end
-        if '?' == name or '*' == name
+        if ['?', '*'].include?(name)
           match = nodes
         elsif '^' == name[0..0] # 1.8.7 thinks name[0] is a fixnum
           case name[1..-1]
-           when 'Element'
+          when 'Element'
             match = nodes.select { |e| e.is_a?(Element) }
-           when 'String', 'Text'
+          when 'String', 'Text'
             match = nodes.select { |e| e.is_a?(String) }
           when 'Comment'
             match = nodes.select { |e| e.is_a?(Comment) }
@@ -364,7 +377,7 @@ module Ox
           when 'DocType'
             match = nodes.select { |e| e.is_a?(DocType) }
           else
-            #puts "*** no match on #{name}"
+            # puts "*** no match on #{name}"
             match = []
           end
         else
@@ -381,7 +394,7 @@ module Ox
           when '>'
             match = index <= match.size ? match[index + 1..-1] : []
           when '@'
-            k,v = step[i..-2].split('=')
+            k, v = step[i..-2].split('=')
             if v
               match = match.select { |n| n.is_a?(Element) && (v == n.attributes[k.to_sym] || v == n.attributes[k]) }
             else
@@ -427,6 +440,7 @@ module Ox
     # - +found+ [Array] An array of Ox::Element
     def recursive_children_removal(found)
       return if found.empty?
+
       nodes.tap do |ns|
         # found.delete(n.object_id) stops looking for an already found object_id
         ns.delete_if { |n| found.include?(n.object_id) ? found.delete(n.object_id) : false }
@@ -438,6 +452,7 @@ module Ox
 
     def name_matchs?(pat, id)
       return false unless pat.length == id.length
+
       pat.length.times { |i| return false unless '_' == id[i] || pat[i] == id[i] }
       true
     end
