@@ -1,8 +1,6 @@
-
 require 'ox'
 
 module Ox
-
   # This is an alternative parser for the stdlib xmlrpc library. It makes
   # use of Ox and is based on REXMLStreamParser. To use it set is as the
   # parser for an XMLRPC client:
@@ -14,6 +12,7 @@ module Ox
   class StreamParser < XMLRPC::XMLParser::AbstractStreamParser
     # Create a new instance.
     def initialize
+      super
       @parser_class = OxParser
     end
 
@@ -21,13 +20,13 @@ module Ox
     class OxParser < Ox::Sax
       include XMLRPC::XMLParser::StreamParserMixin
 
-      alias :text :character
-      alias :end_element :endElement
-      alias :start_element :startElement
+      alias text character
+      alias end_element endElement
+      alias start_element startElement
 
       # Initiates the sax parser with the provided string.
       def parse(str)
-        Ox.sax_parse(self, StringIO.new(str), :symbolize => false, :convert_special => true)
+        Ox.sax_parse(self, StringIO.new(str), symbolize: false, convert_special: true)
       end
     end
   end
